#
# spec file for package budgie-control-center
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           budgie-control-center
Version:        1.3.0+0
Release:        4.1
Summary:        Fork of GNOME Control Center for Budgie 10
License:        GPL-2.0-or-later AND LGPL-3.0-or-later 
Group:          System/GUI/Other
URL:            https://github.com/BuddiesOfBudgie/budgie-control-center
Source0:        %{name}-%{version}.tar.xz
# The color panel requires colord to be present for the glib schema
Requires:       colord
# The color panel interacts with binaries from gnome-color-manager
Requires:       gnome-color-manager
# The online accounts panel interacts with binaries and icons from gnome-online-accounts
Requires:       gnome-online-accounts
BuildRequires:  cups-devel
BuildRequires:  meson
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(cheese)
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(colord-gtk)
BuildRequires:  pkgconfig(gcr-3)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-bluetooth-1.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gnome-settings-daemon)
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(gsound)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libnma)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libwacom)
BuildRequires:  pkgconfig(malcontent-0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(mm-glib)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(pwquality)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(udisks2)
BuildRequires:  pkgconfig(upower-glib)
Requires:       gnome-bluetooth = 3.34.5

%description
Fork of GNOME Control Center for Budgie 10

%package bash-completion
Summary:        Bash Completion for Budgie Control Center
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
This package contains the Bash Completion for Budgie Control Center

%lang_package

%prep
%autosetup -p1

%build
%meson -Ddocumentation=true -Dmalcontent=true
%meson_build

%install
%meson_install
%find_lang %{name} --all-name
rm %{buildroot}%{_datadir}/polkit-1/rules.d/budgie-control-center.rules

%files
%doc README.md
%{_bindir}/*
%{_datadir}/metainfo/budgie-control-center.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.buddiesofbudgie.ControlCenter.service
%{_datadir}/glib-2.0/schemas/org.buddiesofbudgie.ControlCenter.gschema.xml
%{_datadir}/budgie-control-center
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/pixmaps/budgie-faces
%{_datadir}/pixmaps/budgie-logo.png
%{_datadir}/polkit-1/actions/org.buddiesofbudgie.controlcenter.datetime.policy
%{_datadir}/polkit-1/actions/org.buddiesofbudgie.controlcenter.remote-login-helper.policy
%{_datadir}/polkit-1/actions/org.buddiesofbudgie.controlcenter.user-accounts.policy
# We do not package gnome-control-center.rules
#{_datadir}/polkit-1/rules.d/gnome-control-center.rules
%{_datadir}/sounds/budgie
%{_libexecdir}/budgie-cc-remote-login-helper
%{_libexecdir}/budgie-control-center-print-renderer
%{_mandir}/man1/budgie-control-center.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/budgie-control-center

%files lang -f %{name}.lang

%changelog
* Mon Feb 19 2024 Lubos Kocman <lubos.kocman@suse.com>
- Add LGPL-3.0-or-later based on legaldb review
  cc-tls-certificate.c/.h are under LGPL-3.0+
* Thu Feb  1 2024 Callum Farmer <gmbr3@opensuse.org>
- GNOME Bluetooth v1 will stick around until we can remove it
  from here - hopefully very soon
* Fri Nov 17 2023 Callum Farmer <gmbr3@opensuse.org>
- Dependencies changed for 15.6 (boo#1217233):
  * BR pkgconfig(krb5)
* Tue Aug 29 2023 gmbr3@opensuse.org
- Update to version 1.3.0+0:
  * shell: fix visibility check for rows and avoid empty searches
  * shell: avoid activating panel from an empty search
  * Set last-panel only for noncrashing panels
  * network: Increase maximum MTU value from 10000 to 65536
  * display: Removed the loop from the snapping function
  * display: Try snapping all the displays after a config change
  * sound: Prevent duplicate sound device entries
  * common: hostname-entry: Update hostname only after apply is
    clicked
  * usage: Fix confirmation dialog when clearing history
  * thunderbold: Don't cast CcBoltPanel when cancelled
  * user-accounts: close CcAvatarChooser before showing
    GtkFileChooser
  * user-accounts: disallow commas in real name
  * printers: Use CUPS dest API for printing test page
    instead CUPS IPP API
  * keyboard: country matches should not be shown under a
    language name.
  * display: Add 32:9 to known aspect ratios
  * sound: Add a "None" option to the alert chooser
  * sound: Update sounds directory mtime when changing alert
  * sound: Don't flip the balance and fade sliders in RTL
  * Rework cc-usage-panel.c to display dialog on history
    clearance
  * Update POT for the latest translatables
  * Add support for switching the file manager
* Sun Feb  5 2023 gmbr3@opensuse.org
- Update to version 1.2.0+0:
  * thunderbolt: Ensure client and devices exist when setting
    visibility
  * thunderbolt: Hide panel if there's no thunderbolt hardware
  * info-overview: Remove "Mesa" prefix for Intel Iris driver
  * wwan: wait for apn_list to exist to add SIM providers
  * wwan: Set apn access method before adding to list
  * wwan: Update apn list only if device is available
  * wwan: Track apn list updates
  * Better english for the duplicate fingerprint
  * user-account: Return duplicate notification when the finger is
    exist
  * info-overview: Add "Kernel Version" row
  * info: Make get_hardware_model use a hostnamed property getter
  * net-device-ethernet: Don't check device iface name
  * net-device-ethernet: Prevent double free
  * network: Fixed Network profiles shown on wrong device
  * network: Fix an assertion failure
  * cc-printers-panel: don't show two Add Printer buttons at once
* Thu Oct  6 2022 gmbr3@opensuse.org
- Update to version 1.1.1+0:
  * Update background preview to look more like Budgie
  * Ensure VNC/RDP remote control settings is honored
  * Handle keybindings extraction
  * More comprehensive C string extraction
  * panels: wwan: Add WWAN 5G connection support
* Mon Aug  8 2022 gmbr3@opensuse.org
- Update to version 1.1.0+0:
  * Update GLib dependency to 2.70
  * power: Remove support for power-profiles-daemon < 0.9.0
  * build: Add script to detect files in XDG_DATA_DIRS
  * sharing: Turn off VNC gsettings key when turning off VNC (CVE-2022-1736, lp#1971415)
  * sharing: Turn off RDP gsettings key when turning off RDP (lp#1971415)
  * applications: Switch to g_spawn_check_wait_status()
  * applications: Properly protect against NULL app_id
  * wacom: Explicitly discard input from touchscreens
  * wacom: Allow NULL monitors in calibration
  * wwan: Make sure secrets are set when querying connection APN password
  * display: Always show refresh rate
  * network: Fix saving passwords for non-wifi connections
  * build: Bump required gsettings-desktop-schemas version
  * ua: Use the new high contrast key
  * datetime: Remove tzname_daylight
  * keyboard-shortcut-editor: fix leak of accel string
  * keyboard-item: fix leak on unused CcKeyCombo
  * keyboard-manager: fix leak of section list store
  * common: Fix leak of GUdevDevice
  * network: fix critical when opening VPN details page
  * wacom: Add scenario tester
  * wacom: Add a fake stylus when mocking a tablet
  * wacom: Split off notebook switching for detected stylus
  * wacom: Print errors for libwacom_new_from_*() calls
  * info-overview: Allow changing "Device Name" by pressing "Enter"
  * small typo
  * Ensure buddies gresource includes sound test icons
  * Remove Python from dependencies
  * Fix typo in feature template
  * Edit typo in bug_report template
* Fri May 27 2022 gmbr3@opensuse.org
- Update to version 1.0.2+0:
  * Add missing systemd-service file for vnc sharing
  * v1.0.2 version bump
  * Rework VNC screensharing to work with GNOME 42 version of
    GNOME Remote Desktop
  * Rework fractional scaling to disable the lock-screen
    GNOME/Budgie screensaver goes into a flash loop when
    fractional scaling options are used.
  * Move some items out to fix some fallback.
  * Enable setting a dark distributor logo for Fedora.
  * build: Bump required gsettings-desktop-schemas version
  * small typo
  * Ensure buddies gresource includes sound test icons
  * Correct build issues with documentation meson option/disable
    wayland building as a default
  * Bump microrelease
  * Reorganize directories to match budgie-desktop
  * Port: Add individual app icons
  * Fix lintian reported typo
  * network: Fix OWE settings
* Thu Apr 14 2022 Callum Farmer <gmbr3@opensuse.org>
- Split out bash completion into subpackage
* Tue Mar  8 2022 gmbr3@opensuse.org
- Initial version 1.0.0+0
- Polkit security review (boo#1195023)
